@@ -3,6 +3,7 @@ import itertools
 import inspect
 from functools import partial
 from collections import OrderedDict
+from pythonwhat import test_funcs
 
 TEST_NAMES = [
     "test_mc",
@@ -32,12 +33,12 @@ SUB_TESTS = {
     "test_if_else": ['test', 'body', 'orelse'],
     "test_if_exp": ['test', 'body', 'orelse'],
     "test_list_comp": ['comp_iter', 'body', 'ifs'],
-    "test_correct": ['check', 'diagnose'],
+    "check_correct": ['check', 'diagnose'],
     "test_for_loop": ['for_iter', 'body', 'orelse'],
     "test_while_loop": ['test', 'body', 'orelse'],
     "test_with": ['context_tests', 'body'],
     "test_function_definition": ['body'],
-    "test_or": ['tests']
+    "check_or": ['tests']
 }
 
 class Tree(object):
@@ -97,8 +98,12 @@ class Node(object):
             ba.apply_defaults()
             return ba.arguments['state']
 
+    def __str__(self):
+        # TODO print function signature without defaults (or with)
+        return pp.pformat(self.data)
+
     def __iter__(self):
-        return iter(self.child_list)
+        for c in self.child_list: yield c
 
     def partial(self):
         """Return partial of original function call"""
@@ -137,13 +142,6 @@ class Node(object):
         if self.parent: return self.parent.depth + 1
         else: return 0
 
-    def __str__(self):
-        # TODO print function signature without defaults (or with)
-        return pp.pformat(self.data)
-
-    def __iter__(self):
-        for c in self.child_list: yield c
-
 class NodeList(Node):
     def partial(self):
         return [node.partial() for node in self.child_list]
@@ -190,12 +188,13 @@ class Probe(object):
         for st in self.sub_tests:     # TODO: auto sub test detection
             if st in da and da[st]:
                 self.build_sub_test_nodes(da[st], self.tree, this_node, st)
+
         # Second pass to build node and all its children into a subtest
-        for n in this_node.descend(include_me=True):
-            if n.updated:         # already built, e.g. node used multiple times
+        for node in this_node.descend(include_me=True):
+            if node.updated:         # already built, e.g. node used multiple times
                 continue
             else:
-                n.update_child_calls()
+                node.update_child_calls()
         
         if self.eval_on_call: return this_node()
         else:                 return this_node
@@ -212,7 +211,7 @@ class Probe(object):
             nl = NodeList(name = "List", arg_name = arg_name)
             node.add_child(nl)
             for ii, f in enumerate(test): Probe.build_sub_test_nodes(f, tree, nl, str(ii))
-        elif isinstance(test, Node): 
+        elif isinstance(test, Node):
             # test was a lambdaless subtest call, which produced a node
             # so need to tell it what its arg_name was on parent test
             test.arg_name = arg_name
@@ -222,20 +221,17 @@ class Probe(object):
             # since either may contain multiple subtests, we put them in a node list
             nl = NodeList(name = "ListDeferred", arg_name = arg_name)
             node.add_child(nl)
-            # only when lambda or function containing subtests: execute to further build out tree
-            if inspect.isfunction(test):
-                if tree is not None:
-                    prev_node, tree.crnt_node = tree.crnt_node, nl
-                    test()
-                    tree.crnt_node = prev_node
-                else:
-                    test()
+            if tree is not None:
+                prev_node, tree.crnt_node = tree.crnt_node, nl
+                test()
+                tree.crnt_node = prev_node
+            else:
+                test()
         elif test is not None:
             raise Exception("Expected a function or list/tuple/dict of functions")
 
 
-def create_test_probes(context):
+def build_probe_context():
     tree = Tree()
-    new_context = {s: Probe(tree, context[s]) for s in TEST_NAMES}
-    new_context.update({k:v for k,v in context.items() if k not in new_context})
-    return tree, new_context
+    probe_context = {s: Probe(tree, getattr(test_funcs, s)) for s in TEST_NAMES}
+    return tree, probe_context
